@@ -73,14 +73,13 @@ if __name__ == '__main__':
         axes[1].legend()
 
         fileFrame = pd.DataFrame([{'setting': setting, 'material': m[1], 'cube': cube} for setting in settings for m in materials for cube in glob(
-            os.path.join(rootDir, setting, 'er', m[0],'Cell*'))])  # Convert the folder structure to a dataframe labeled with NA setting, Material, and the ImCube objects.
-        df = loadAndProcess(fileFrame, processIm, parallel=True)  # Returns a dataframe matching the form of `fileFrame` except the filepaths have been replaced with ImCube objects (The filepaths have been loaded and processed using the `processIms` function.).
+            os.path.join(rootDir, setting, 'er', m[0],'Cell*'))])  # Convert the folder structure to a dataframe labeled with NA setting, Material, and the PwsCube objects.
+        df = loadAndProcess(fileFrame, processIm, parallel=True)  # Returns a dataframe matching the form of `fileFrame` except the filepaths have been replaced with PwsCube objects (The filepaths have been loaded and processed using the `processIms` function.).
 
         theoryR = er.getTheoreticalReflectances(list(zip(*materials))[1], df['cube'][0].wavelengths, numericalAperture=na)
         matCombos = er.generateMaterialCombos(list(zip(*materials))[1])
         if plotResults:
-            verts = random.choice(df['cube']).selectLassoROI()
-            roi = Roi.fromVerts(verts, df['cube'][0].data.shape[:2])
+            roi = random.choice(df['cube']).selectLassoROI()
             er.plotExtraReflection(df, theoryR, matCombos, na, roi, plotReflectionImages=False)
             with PdfPages(os.path.join(rootDir, "figs.pdf")) as pp:
                 for i in plt.get_fignums():
