@@ -23,18 +23,15 @@ import typing
 from io import IOBase
 from typing import Optional, Dict, List
 import pickle
-
 from PyQt5 import QtCore
 from PyQt5.QtCore import QObject, QThread
 from PyQt5.QtWidgets import QMessageBox, QWidget
-
 import httplib2
 from googleapiclient.discovery import build
 from google_auth_oauthlib.flow import InstalledAppFlow
 from google.auth.transport.requests import Request
 from googleapiclient.http import MediaIoBaseDownload, MediaFileUpload
 from google.auth.exceptions import TransportError
-
 from pwspy.dataTypes import ERMetaData
 from pwspy_gui.PWSAnalysisApp import applicationVars
 from pwspy_gui.sharedWidgets.dialogs import BusyDialog
@@ -75,9 +72,23 @@ class ERManager:
         indexPath = os.path.join(self._directory, 'index.json')
         if not os.path.exists(indexPath) and not self.offlineMode:
             self.download('index.json')
-        self.dataComparator = ERDataComparator(self._downloader, self._directory)
+        self.localDirectory = ERDataDirectory(self._directory)
+        if not self.offlineMode:
+            self.onlineDirectory = EROnlineDirectory(self._downloader)
+        else:
+            self.onlineDirectory = None
 
-    def _logIn(self, parentWidget: QWidget) -> typing.Tuple[bool, ERDownloader]:
+    def _logIn(self, parentWidget: Optional[QWidget]) -> typing.Tuple[bool, Optional[ERDownloader]]:
+        """
+        Try logging in to google drive
+        Args:
+            parentWidget: If a message box needs to be displayed this widget will act as the parent of the message box.
+
+        Returns:
+            offlineMode: True if connection failed.
+            downloader: A download helper object. Will be none if connection failed.
+
+        """
         logger = logging.getLogger(__name__)
         logger.debug("Calling ERDownloader.getCredentials")
         creds = ERDownloader.getCredentials(applicationVars.googleDriveAuthPath)
@@ -121,11 +132,7 @@ class ERManager:
     def getMetadataFromId(self, idTag: str) -> ERMetaData:
         """Given the unique idTag string for an ExtraReflectanceCube this will search the index.json and return the
         ERMetaData file. If it cannot be found then an `IndexError will be raised."""
-        try:
-            match = [item for item in self.dataComparator.local.index.cubes if item.idTag == idTag][0]
-        except IndexError:
-            raise IndexError(f"An ExtraReflectanceCube with idTag {idTag} was not found in the index.json file at {self._directory}.")
-        return ERMetaData.fromHdfFile(self._directory, match.name)
+        return self.localDirectory.getMetadataFromId(idTag)
 
 
 class ERDownloader:
